// static/script.js
document.addEventListener('DOMContentLoaded', function() {
    // Terminal and logging functionality
    const terminalOutput = document.getElementById('terminalOutput');
    const rawLogs = document.getElementById('rawLogs');
    let allLogs = [];

    // Helper function to add log entries to terminal
    function addLogEntry(log, type = 'normal') {
        const line = document.createElement('div');
        line.className = 'terminal-line';

        // Format the log based on type
        if (typeof log === 'string') {
            if (log.startsWith('[+]')) {
                line.innerHTML = `<span class="text-success">${log}</span>`;
            } else if (log.startsWith('[-]')) {
                line.innerHTML = `<span class="text-info">${log}</span>`;
            } else if (log.startsWith('[!]')) {
                line.innerHTML = `<span class="text-danger">${log}</span>`;
            } else if (log.startsWith('[*]')) {
                line.innerHTML = `<span class="text-warning">${log}</span>`;
            } else {
                line.textContent = log;
            }
        } else {
            line.textContent = JSON.stringify(log, null, 2);
        }

        // Add to terminal and raw logs
        terminalOutput.appendChild(line);
        terminalOutput.scrollTop = terminalOutput.scrollHeight;

        // Add to raw logs
        allLogs.push(log);
        rawLogs.textContent = allLogs.join('\n');
        rawLogs.scrollTop = rawLogs.scrollHeight;
    }

    // Event listeners for buttons
    const initializeBtn = document.getElementById('initializeBtn');
    const reconBtn = document.getElementById('reconBtn');
    const exploitBtn = document.getElementById('exploitBtn');
    const privescBtn = document.getElementById('privescBtn');
    const exfilBtn = document.getElementById('exfilBtn');
    const clearTerminalBtn = document.getElementById('clearTerminal');
    const downloadLogsBtn = document.getElementById('downloadLogs');
    const reportBreachBtn = document.getElementById('reportBreachBtn');

    let targetIp = document.getElementById('targetIp').value;
    let targetPort = document.getElementById('targetPort').value;

    // Initialize the exploit
    initializeBtn.addEventListener('click', function() {
        targetIp = document.getElementById('targetIp').value;
        targetPort = document.getElementById('targetPort').value;

        if (!targetIp || !targetPort) {
            addLogEntry('[!] Error: Target IP and Port are required', 'error');
            return;
        }

        // Simulate initialization
        addLogEntry(`[+] Initializing exploit against target ${targetIp}:${targetPort}`);

        fetch('/api/exploit/init', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                target_ip: targetIp,
                target_port: targetPort
            }),
        })
        .then(response => response.json())
        .then(data => {
            addLogEntry(`[+] Exploit initialized for CVE-2025-30065`);
            addLogEntry(`[+] Target: ${data.target}`);
            addLogEntry(`[+] Timestamp: ${data.timestamp}`);
            addLogEntry(`[*] Ready for reconnaissance phase`);

            // Enable the reconnaissance button
            reconBtn.disabled = false;

            // Load the summary tab content
            loadSummaryContent();
            loadMitigationContent();
        })
        .catch(error => {
            addLogEntry(`[!] Error initializing exploit: ${error}`, 'error');
        });
    });

    // Reconnaissance phase
    reconBtn.addEventListener('click', function() {
        addLogEntry(`[+] Starting reconnaissance phase against ${targetIp}:${targetPort}`);

        fetch('/api/exploit/recon', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                target_ip: targetIp,
                target_port: targetPort
            }),
        })
        .then(response => response.json())
        .then(data => {
            // Update status
            document.getElementById('reconStatus').textContent = 'Complete';
            document.getElementById('reconStatus').className = 'badge bg-success';

            // Add logs to terminal
            data.logs.forEach(log => {
                addLogEntry(log);
            });

            // Add services information
            addLogEntry(`[+] Services detected:`);
            data.details.services.forEach(service => {
                addLogEntry(`[-] ${service.name}: ${service.port} (v${service.version})`);
            });

            // Add vulnerability information
            addLogEntry(`[+] Vulnerabilities detected:`);
            data.details.vulnerabilities.forEach(vuln => {
                addLogEntry(`[!] ${vuln.cve} in ${vuln.component}: ${vuln.status}`);
            });

            addLogEntry(`[*] Reconnaissance complete. Ready for exploitation.`);

            // Enable the exploit button
            exploitBtn.disabled = false;
        })
        .catch(error => {
            addLogEntry(`[!] Error during reconnaissance: ${error}`, 'error');
        });
    });

    // Exploitation phase
    exploitBtn.addEventListener('click', function() {
        addLogEntry(`[+] Starting exploitation phase against ${targetIp}:${targetPort}`);

        fetch('/api/exploit/exploit', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                target_ip: targetIp,
                target_port: targetPort
            }),
        })
        .then(response => response.json())
        .then(data => {
            // Update status
            document.getElementById('exploitStatus').textContent = 'Complete';
            document.getElementById('exploitStatus').className = 'badge bg-success';

            // Add logs to terminal
            data.logs.forEach(log => {
                addLogEntry(log);
            });

            addLogEntry(`[+] Exploit technique: ${data.details.exploit_technique}`);
            addLogEntry(`[+] Vulnerable component: ${data.details.vulnerability_component}`);
            addLogEntry(`[+] Shell type: ${data.details.shell_type}`);
            addLogEntry(`[+] Shell user: ${data.details.shell_user}`);
            addLogEntry(`[+] Shell status: ${data.details.shell_status}`);

            addLogEntry(`[*] Exploitation complete. Ready for privilege escalation.`);

            // Enable the privesc button
            privescBtn.disabled = false;
        })
        .catch(error => {
            addLogEntry(`[!] Error during exploitation: ${error}`, 'error');
        });
    });

    // Privilege escalation phase
    privescBtn.addEventListener('click', function() {
    addLogEntry(`[+] Starting privilege escalation on ${targetIp}`);

    fetch('/api/exploit/privilege', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            target_ip: targetIp,
            target_port: targetPort
        }),
    })
    .then(response => response.json())
    .then(data => {
        // Safely update status
        const privescStatusEl = document.getElementById('privescStatus');
        if (privescStatusEl) {
            privescStatusEl.textContent = 'Complete';
            privescStatusEl.className = 'badge bg-success';
        }

        // Add logs to terminal
        if (data.logs && Array.isArray(data.logs)) {
            data.logs.forEach(log => {
                addLogEntry(log);
            });
        }

        if (data.details) {
            addLogEntry(`[+] Initial user: ${data.details.initial_user}`);
            addLogEntry(`[+] Privilege escalation vector: ${data.details.escalation_vector}`);
            addLogEntry(`[+] Final user: ${data.details.final_user}`);
            addLogEntry(`[+] Privileges: ${data.details.privileges}`);
        }

        addLogEntry(`[*] Privilege escalation complete. Ready for data exfiltration.`);

        // Enable the exfil button
        const exfilBtn = document.getElementById('exfilBtn');
        if (exfilBtn) {
            exfilBtn.disabled = false;
        }
    })
    .catch(error => {
        addLogEntry(`[!] Error during privilege escalation: ${error}`, 'error');
    });
});

    // Data exfiltration phase
exfilBtn.addEventListener('click', function() {
    addLogEntry(`[+] Starting data exfiltration from ${targetIp}`);

    fetch('/api/exploit/exfiltration', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            target_ip: targetIp,
            target_port: targetPort
        }),
    })
    .then(response => response.json())
    .then(data => {
        // Safely update status
        const exfilStatusEl = document.getElementById('exfilStatus');
        if (exfilStatusEl) {
            exfilStatusEl.textContent = 'Complete';
            exfilStatusEl.className = 'badge bg-success';
        } else {
            console.error('exfilStatus element not found');
        }

        // Add logs to terminal
        if (data.logs && Array.isArray(data.logs)) {
            data.logs.forEach(log => {
                addLogEntry(log);
            });
        }

        if (data.details) {
            addLogEntry(`[+] Files exfiltrated: ${data.details.files_exfiltrated || 'Unknown'}`);
            addLogEntry(`[+] Data size: ${data.details.data_size || 'Unknown'}`);
            addLogEntry(`[+] Exfiltration method: ${data.details.exfiltration_method || 'Unknown'}`);

            if (data.details.sensitive_data_types && Array.isArray(data.details.sensitive_data_types)) {
                addLogEntry(`[+] Sensitive data types:`);
                data.details.sensitive_data_types.forEach(type => {
                    addLogEntry(`[-] ${type}`);
                });
            }

            addLogEntry(`[+] Cleanup status: ${data.details.cleanup_status || 'Unknown'}`);
        }

        addLogEntry(`[*] Exploitation chain complete!`);

        // Show the data exfiltration modal
        const exfilModalElement = document.getElementById('exfilModal');
        if (exfilModalElement) {
            const exfilModal = new bootstrap.Modal(exfilModalElement);
            exfilModal.show();
        }
    })
    .catch(error => {
        addLogEntry(`[!] Error during data exfiltration: ${error}`, 'error');
    });
});

    // Clear terminal button
    clearTerminalBtn.addEventListener('click', function() {
        terminalOutput.innerHTML = '';
        addLogEntry(`[+] Terminal cleared`);
    });

    // Download logs button
    downloadLogsBtn.addEventListener('click', function() {
        const blob = new Blob([allLogs.join('\n')], { type: 'text/plain' });
        const url = URL.createObjectURL(blob);
        const a = document.createElement('a');
        a.href = url;
        a.download = `CVE-2025-30065_exploit_logs_${new Date().toISOString().slice(0,10)}.txt`;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        URL.revokeObjectURL(url);
    });

    // Report breach button (just for show)
    reportBreachBtn.addEventListener('click', function() {
        alert('In a real scenario, this would report the security breach to the appropriate security team. This is a simulation only.');
    });

    // Load vulnerability summary content
    function loadSummaryContent() {
        const summaryContent = document.getElementById('summaryContent');

        fetch('/api/exploit/summary')
        .then(response => response.json())
        .then(data => {
            let html = `
            <div class="mb-4">
                <h4 class="text-danger">${data.cve_id}: ${data.name}</h4>
                <p>${data.description}</p>
                <div class="row">
                    <div class="col-md-6">
                        <ul class="list-group mb-3">
                            <li class="list-group-item bg-dark text-light d-flex justify-content-between">
                                <span>Severity:</span>
                                <span class="badge bg-danger">${data.severity}</span>
                            </li>
                            <li class="list-group-item bg-dark text-light d-flex justify-content-between">
                                <span>Affected Versions:</span>
                                <span>${data.affected_versions}</span>
                            </li>
                            <li class="list-group-item bg-dark text-light d-flex justify-content-between">
                                <span>Attack Vector:</span>
                                <span>${data.attack_vector}</span>
                            </li>
                            <li class="list-group-item bg-dark text-light d-flex justify-content-between">
                                <span>Complexity:</span>
                                <span>${data.complexity}</span>
                            </li>
                            <li class="list-group-item bg-dark text-light d-flex justify-content-between">
                                <span>Authentication:</span>
                                <span>${data.authentication}</span>
                            </li>
                        </ul>
                    </div>
                    <div class="col-md-6">
                        <div class="card bg-dark border-danger h-100">
                            <div class="card-header bg-danger text-white">
                                <h5 class="mb-0">Impact Assessment</h5>
                            </div>
                            <div class="card-body">
                                <div class="mb-2">
                                    <span>Confidentiality:</span>
                                    <div class="progress mb-2">
                                        <div class="progress-bar bg-danger" role="progressbar" style="width: 100%;" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100">${data.impact.confidentiality}</div>
                                    </div>
                                </div>
                                <div class="mb-2">
                                    <span>Integrity:</span>
                                    <div class="progress mb-2">
                                        <div class="progress-bar bg-danger" role="progressbar" style="width: 100%;" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100">${data.impact.integrity}</div>
                                    </div>
                                </div>
                                <div>
                                    <span>Availability:</span>
                                    <div class="progress">
                                        <div class="progress-bar bg-danger" role="progressbar" style="width: 100%;" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100">${data.impact.availability}</div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="card bg-dark border-secondary">
                <div class="card-header bg-dark border-secondary">
                    <h5>Technical Details</h5>
                </div>
                <div class="card-body">
                    <pre class="mb-0">${data.details}</pre>
                </div>
            </div>
            `;

            summaryContent.innerHTML = html;
        })
        .catch(error => {
            console.error('Error loading summary:', error);
            summaryContent.innerHTML = `<div class="alert alert-danger">Error loading vulnerability details: ${error}</div>`;
        });
    }

    // Load mitigation content
    function loadMitigationContent() {
        const mitigationContent = document.getElementById('mitigationContent');

        fetch('/api/exploit/mitigation')
        .then(response => response.json())
        .then(data => {
            let html = `
            <div class="mb-4">
                <div class="alert alert-success">
                    <i class="fas fa-shield-alt me-2"></i>A patch is available! Update to <strong>${data.fixed_versions}</strong>
                </div>

                <div class="row mb-4">
                    <div class="col-md-12">
                        <div class="card bg-dark border-success">
                            <div class="card-header bg-success text-dark">
                                <h5 class="mb-0"><i class="fas fa-cogs me-2"></i>Recommended Actions</h5>
                            </div>
                            <div class="card-body">
                                <ol class="list-group list-group-numbered">
            `;

            data.workarounds.forEach(workaround => {
                html += `<li class="list-group-item bg-dark text-light border-secondary">${workaround}</li>`;
            });

            html += `
                                </ol>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="row mb-4">
                    <div class="col-md-12">
                        <div class="card bg-dark border-info">
                            <div class="card-header bg-info text-dark">
                                <h5 class="mb-0"><i class="fas fa-search me-2"></i>Detection Methods</h5>
                            </div>
                            <div class="card-body">
                                <ul class="list-group">
            `;

            data.detection_methods.forEach(method => {
                html += `<li class="list-group-item bg-dark text-light border-secondary"><i class="fas fa-check-circle me-2 text-info"></i>${method}</li>`;
            });

            html += `
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card bg-dark border-secondary">
                    <div class="card-header bg-dark border-secondary">
                        <h5><i class="fas fa-code-branch me-2"></i>Patch Details</h5>
                    </div>
                    <div class="card-body">
                        <pre class="mb-0">${data.patch_details}</pre>
                    </div>
                </div>
            </div>
            `;

            mitigationContent.innerHTML = html;
        })
        .catch(error => {
            console.error('Error loading mitigation:', error);
            mitigationContent.innerHTML = `<div class="alert alert-danger">Error loading mitigation information: ${error}</div>`;
        });
    }

    // Initialize with some startup text
    addLogEntry(`[+] Apache Parquet RCE Simulator loaded - CVE-2025-30065`);
    addLogEntry(`[*] Please configure target parameters and click Initialize`);
});